imblearn.under_sampling.CondensedNearestNeighbour
=================================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: CondensedNearestNeighbour

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CondensedNearestNeighbour.__init__
      ~CondensedNearestNeighbour.fit
      ~CondensedNearestNeighbour.fit_sample
      ~CondensedNearestNeighbour.get_params
      ~CondensedNearestNeighbour.sample
      ~CondensedNearestNeighbour.set_params
   
   

   
   
   